diff -Nur net-tools.orig/ifconfig.c net-tools-1.60/ifconfig.c
--- net-tools.orig/ifconfig.c	Fri Apr 13 20:25:18 2001
+++ net-tools-1.60/ifconfig.c	Mon Jul 15 15:35:45 2002
@@ -92,6 +92,7 @@
 int opt_v = 0;			/* debugging output flag        */
 
 int addr_family = 0;		/* currently selected AF        */
+int ip_type = TYPE_UNSET;
 
 /* for ipv4 add/del modes */
 static int get_nmbc_parent(char *parent, unsigned long *nm, 
@@ -120,6 +121,19 @@
     return res; 
 }
 
+static void if_ip_print(char * ifname,int type)
+{
+    if (ifname) {
+	int res;
+        struct interface * ife;
+        ife = lookup_interface(ifname);
+        res = do_if_fetch(ife);
+        if (res >= 0) {
+	    ip_print(ife,type);
+        }
+    }
+}
+
 /* Set a certain interface flag. */
 static int set_flag(char *ifname, short flag)
 {
@@ -174,7 +188,7 @@
 
 static void usage(void)
 {
-    fprintf(stderr, _("Usage:\n  ifconfig [-a] [-i] [-v] [-s] <interface> [[<AF>] <address>]\n"));
+    fprintf(stderr, _("Usage:\n  ifconfig [-a] [-i] [-v] [-s] [--ip|--bc|--nm] <interface> [[<AF>] <address>]\n"));
 #if HAVE_AFINET
     fprintf(stderr, _("  [add <address>[/<prefixlen>]]\n"));
     fprintf(stderr, _("  [del <address>[/<prefixlen>]]\n"));
@@ -265,7 +279,28 @@
 
 	else if (!strcmp(*argv, "-v"))
 	    opt_v = 1;
-	
+
+	else if (!strcmp(*argv,"--ip")) {
+          if (*(argv+1)) {
+            ip_type = TYPE_IP;
+	  } else
+	    usage();
+	}
+
+	else if (!strcmp(*argv,"--bc")) {
+          if (*(argv+1)) {
+	   ip_type = TYPE_BC;
+	  } else
+	    usage();
+	}
+	    
+	else if (!strcmp(*argv,"--nm")) {
+          if (*(argv+1)) {
+            ip_type = TYPE_NM;
+	  } else
+	    usage();
+        }
+
 	else if (!strcmp(*argv, "-V") || !strcmp(*argv, "-version") ||
 	    !strcmp(*argv, "--version"))
 	    version();
@@ -300,6 +335,12 @@
     /* No. Fetch the interface name. */
     spp = argv;
     safe_strncpy(ifr.ifr_name, *spp++, IFNAMSIZ);
+
+    if (ip_type != TYPE_UNSET) {
+      if_ip_print(ifr.ifr_name,ip_type);
+      exit(0);
+    }
+
     if (*spp == (char *) NULL) {
 	int err = if_print(ifr.ifr_name);
 	(void) close(skfd);
diff -Nur net-tools.orig/include/interface.h net-tools-1.60/include/interface.h
--- net-tools.orig/include/interface.h	Sat Feb 10 20:24:25 2001
+++ net-tools-1.60/include/interface.h	Mon Jul 15 15:36:36 2002
@@ -73,6 +73,8 @@
 
 extern void ife_print(struct interface *ptr);
 
+extern void ip_print(struct interface * ptr, int type);
+
 extern int ife_short;
 
 extern const char *if_port_text[][4];
@@ -87,6 +89,11 @@
 /* Actually it is ifru_ivalue, but that is not present in 2.0 kernel headers */   
 #define ifr_qlen        ifr_ifru.ifru_mtu
 #endif
+
+#define TYPE_IP		0
+#define TYPE_BC 	1
+#define TYPE_NM 	2
+#define TYPE_UNSET 	100
 
 #define HAVE_TXQUEUELEN
 
diff -Nur net-tools.orig/lib/interface.c net-tools-1.60/lib/interface.c
--- net-tools.orig/lib/interface.c	Sat Feb 10 20:31:15 2001
+++ net-tools-1.60/lib/interface.c	Mon Jul 15 15:35:09 2002
@@ -577,6 +577,30 @@
     return res;
 }
 
+void ip_print(struct interface * ptr, int type)
+{
+#if HAVE_AFINET
+    struct aftype * ap = get_afntype(ptr->addr.sa_family);
+    if (ap==NULL)
+        ap = get_afntype(0);
+    if (ptr->has_ip) {
+        switch (type) {
+	case TYPE_IP:
+	    printf("%s",ap->sprint(&ptr->addr,1));
+	    break;
+	case TYPE_BC:
+	    if (ptr->flags && IFF_BROADCAST) {
+                printf("%s",ap->sprint(&ptr->broadaddr,1));
+	    }
+	    break;
+	case TYPE_NM:
+	    printf("%s",ap->sprint(&ptr->netmask,1));
+	    break;
+	}
+    }
+#endif
+}
+
 void ife_print_short(struct interface *ptr)
 {
     printf("%-5.5s ", ptr->name);
